pub enum TileIdError {
InvalidLevel(u32),
InvalidMortonNumber {
morton: i64,
level: u32,
max: u64,
},
ValueTooSmall(i32),
}Expand description
Error returned when constructing or validating a PackedTileId.
Variants
InvalidLevel(u32)
The level is outside the valid range 0..=15.
InvalidMortonNumber
The morton number is outside the valid range for the given level.
Fields
ValueTooSmall(i32)
The packed value is below the minimum valid packed tile id (1 << 16).